You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2005/04/23 00:36:06 UTC

svn commit: r164289 - /directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java

Author: elecharny
Date: Fri Apr 22 15:36:04 2005
New Revision: 164289

URL: http://svn.apache.org/viewcvs?rev=164289&view=rev
Log:
Corrected the typo Heirarchy -> Hierarchy (JIRA DIREVE-153)

Modified:
    directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java

Modified: directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java
URL: http://svn.apache.org/viewcvs/directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java?rev=164289&r1=164288&r2=164289&view=diff
==============================================================================
--- directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java (original)
+++ directory/apacheds/trunk/core/src/main/java/org/apache/ldap/server/db/Database.java Fri Apr 22 15:36:04 2005
@@ -88,9 +88,9 @@
      * Gets the Index mapping the BigInteger primary keys of parents to the 
      * BigInteger primary keys of their children.
      *
      * @return the heirarchy Index
      */
-    Index getHeirarchyIndex();
+    Index getHierarchyIndex();
     
     /**
      * Gets the Index mapping user provided distinguished names of entries as 
@@ -150,11 +150,11 @@
     void setExistanceIndexOn( AttributeType attrType ) throws NamingException;
 
     /**
      * Sets the heirarchy Index.
      *
      * @param attrType the heirarchy Index
      */    
-    void setHeirarchyIndexOn( AttributeType attrType ) throws NamingException;
+    void setHierarchyIndexOn( AttributeType attrType ) throws NamingException;
 
     /**
      * Sets the user provided distinguished name Index.
@@ -88,9 +88,9 @@
      * BigInteger primary keys of their children.
      *
-     * @return the heirarchy Index
+     * @return the hierarchy Index
      */
@@ -150,11 +150,11 @@
 
     /**
-     * Sets the heirarchy Index.
+     * Sets the hierarchy Index.
      *
@@ -150,11 +150,11 @@
      *
-     * @param attrType the heirarchy Index
+     * @param attrType the hierarchy Index
      */    